Author: simon
Date: 2009-12-16 16:55:59 +0000 (Wed, 16 Dec 2009)
New Revision: 1501
Modified:
trunk/batman-adv-kernelland/originator.c
trunk/batman-adv-kernelland/packet.h
trunk/batman-adv-kernelland/proc.c
trunk/batman-adv-kernelland/routing.c
trunk/batman-adv-kernelland/types.h
Log:
staging: batman-adv: consistent spelling of "neighbors"
we have written "neighbors", "neighbours" and bad spelled versions of this
word, this patch should make it consistent.
Signed-off-by: Simon Wunderlich <siwu(a)hrz.tu-chemnitz.de>
Modified: trunk/batman-adv-kernelland/originator.c
===================================================================
--- trunk/batman-adv-kernelland/packet.h 2009-12-16 16:42:46 UTC (rev 1500)
+++ trunk/batman-adv-kernelland/packet.h 2009-12-16 16:55:59 UTC (rev 1501)
@@ -90,7 +90,7 @@
uint8_t entries; /* number of entries behind this struct */
uint8_t ttl; /* TTL */
uint8_t vis_orig[6]; /* originator that informs about its
- * neighbours */
+ * neighbors */
uint8_t target_orig[6]; /* who should receive this packet */
uint8_t sender_orig[6]; /* who sent or rebroadcasted this packet */
} __attribute__((packed));
Modified: trunk/batman-adv-kernelland/proc.c
===================================================================
--- trunk/batman-adv-kernelland/proc.c 2009-12-16 16:42:46 UTC (rev 1500)
+++ trunk/batman-adv-kernelland/proc.c 2009-12-16 16:55:59 UTC (rev 1501)
@@ -404,7 +404,7 @@
from, to, int_part, frac_part);
} else {
seq_printf(seq,
- "%s\t{ router : \"%s\", neighbour : \"%s\", label : %d.%d }",
+ "%s\t{ router : \"%s\", neighbor : \"%s\", label : %d.%d }",
(first_line ? "" : ",\n"), from, to, int_part, frac_part);
}
}
Modified: trunk/batman-adv-kernelland/routing.c
===================================================================
--- trunk/batman-adv-kernelland/types.h 2009-12-16 16:42:46 UTC (rev 1500)
+++ trunk/batman-adv-kernelland/types.h 2009-12-16 16:55:59 UTC (rev 1501)
@@ -75,7 +75,7 @@
uint8_t tq_index;
uint8_t tq_avg;
uint8_t last_ttl;
- unsigned long last_valid; /* when last packet via this neighbour was received */
+ unsigned long last_valid; /* when last packet via this neighbor was received */
TYPE_OF_WORD real_bits[NUM_WORDS];
struct orig_node *orig_node;
struct batman_if *if_incoming;
--- trunk/batman-adv-kernelland/originator.c 2009-12-16 16:42:46 UTC (rev 1500)
+++ trunk/batman-adv-kernelland/originator.c 2009-12-16 16:55:59 UTC (rev 1501)
@@ -74,7 +74,7 @@
{
struct neigh_node *neigh_node;
- bat_dbg(DBG_BATMAN, "Creating new last-hop neighbour of originator\n");
+ bat_dbg(DBG_BATMAN, "Creating new last-hop neighbor of originator\n");
neigh_node = kmalloc(sizeof(struct neigh_node), GFP_ATOMIC);
memset(neigh_node, 0, sizeof(struct neigh_node));
@@ -94,7 +94,7 @@
struct neigh_node *neigh_node;
struct orig_node *orig_node = (struct orig_node *)data;
/* for all neighbours towards this originator ... */
list_for_each_safe(list_pos, list_pos_tmp, &orig_node->neigh_list) {
neigh_node = list_entry(list_pos, struct neigh_node, list);
@@ -159,7 +159,7 @@
return orig_node;
}
-static bool purge_orig_neigbours(struct orig_node *orig_node,
+static bool purge_orig_neighbors(struct orig_node *orig_node,
struct neigh_node **best_neigh_node)
{
struct list_head *list_pos, *list_pos_tmp;
@@ -170,7 +170,7 @@
*best_neigh_node = NULL;
/* for all neighbours towards this originator ... */
list_for_each_safe(list_pos, list_pos_tmp, &orig_node->neigh_list) {
neigh_node = list_entry(list_pos, struct neigh_node, list);
@@ -180,7 +180,7 @@
addr_to_string(neigh_str, neigh_node->addr);
addr_to_string(orig_str, orig_node->orig);
- bat_dbg(DBG_BATMAN, "Neighbour timeout: originator %s, neighbour: %s, last_valid %lu\n", orig_str, neigh_str, (neigh_node->last_valid / HZ));
+ bat_dbg(DBG_BATMAN, "Neighbour timeout: originator %s, neighbor: %s, last_valid %lu\n", orig_str, neigh_str, (neigh_node->last_valid / HZ));
neigh_purged = true;
list_del(list_pos);
@@ -211,7 +211,7 @@
orig_str, (orig_node->last_valid / HZ));
return true;
} else {
- if (purge_orig_neigbours(orig_node, &best_neigh_node))
+ if (purge_orig_neighbors(orig_node, &best_neigh_node))
update_routes(orig_node, best_neigh_node,
orig_node->hna_buff,
orig_node->hna_buff_len);
@@ -94,7 +94,7 @@
struct neigh_node *neigh_node;
struct orig_node *orig_node = (struct orig_node *)data;
- /* for all neighbours towards this originator ... */
+ /* for all neighbors towards this originator ... */
list_for_each_safe(list_pos, list_pos_tmp, &orig_node->neigh_list) {
neigh_node = list_entry(list_pos, struct neigh_node, list);
@@ -170,7 +170,7 @@
*best_neigh_node = NULL;
- /* for all neighbours towards this originator ... */
+ /* for all neighbors towards this originator ... */
list_for_each_safe(list_pos, list_pos_tmp, &orig_node->neigh_list) {
neigh_node = list_entry(list_pos, struct neigh_node, list);
Modified: trunk/batman-adv-kernelland/packet.h
===================================================================
--- trunk/batman-adv-kernelland/routing.c 2009-12-16 16:42:46 UTC (rev 1500)
+++ trunk/batman-adv-kernelland/routing.c 2009-12-16 16:55:59 UTC (rev 1501)
@@ -266,7 +266,7 @@
ethhdr->h_source, if_incoming);
else
bat_dbg(DBG_BATMAN,
- "Updating existing last-hop neighbour of originator\n");
+ "Updating existing last-hop neighbor of originator\n");
orig_node->flags = batman_packet->flags;
neigh_node->last_valid = jiffies;
@@ -444,7 +444,7 @@
orig_neigh_node = get_orig_node(ethhdr->h_source);
/* neighbour has to indicate direct link and it has to
* come via the corresponding interface */
/* if received seqno equals last send seqno save new
* seqno for bidirectional check */
@@ -459,7 +459,7 @@
bit_packet_count(word);
}
- bat_dbg(DBG_BATMAN, "Drop packet: originator packet from myself (via neighbour) \n");
+ bat_dbg(DBG_BATMAN, "Drop packet: originator packet from myself (via neighbor) \n");
return;
}
@@ -520,14 +520,14 @@
update_orig(orig_node, ethhdr, batman_packet,
if_incoming, hna_buff, hna_buff_len, is_duplicate);
/* is single hop (direct) neighbour */
if (is_single_hop_neigh) {
/* mark direct link on incoming interface */
schedule_forward_packet(orig_node, ethhdr, batman_packet,
1, hna_buff_len, if_incoming);
- bat_dbg(DBG_BATMAN, "Forwarding packet: rebroadcast neighbour packet with direct link flag\n");
+ bat_dbg(DBG_BATMAN, "Forwarding packet: rebroadcast neighbor packet with direct link flag\n");
return;
}
Modified: trunk/batman-adv-kernelland/types.h
@@ -444,7 +444,7 @@
orig_neigh_node = get_orig_node(ethhdr->h_source);
- /* neighbour has to indicate direct link and it has to
+ /* neighbor has to indicate direct link and it has to
* come via the corresponding interface */
/* if received seqno equals last send seqno save new
@@ -520,14 +520,14 @@
update_orig(orig_node, ethhdr, batman_packet,
if_incoming, hna_buff, hna_buff_len, is_duplicate);
- /* is single hop (direct) neighbour */
+ /* is single hop (direct) neighbor */
if (is_single_hop_neigh) {
/* mark direct link on incoming interface */
===================================================================